/*
This is a simple player for TVBGONE power codes.
Our player is simple because PIC C18 has easy 
reads from program memory. 

This code was written based on the description 
of the data packing method published on the Adafruit 
website. It should be a clean, black-box rewrite, but 
we'll release it as CC 2.5 Attrib & Share Alike 
out of respect for the original authors.

PIC C18 Player (c) Ian Lesnet 2009
for use with IR Toy v1.0 hardware.
http://dangerousprototypes.com

With credits to:

TV-B-Gone Firmware version 1.2
for use with ATtiny85v and v1.2 hardware
(c) Mitch Altman + Limor Fried 2009
Last edits, August 16 2009

With some code from:
Kevin Timmerman & Damien Good 7-Dec-07

Distributed under Creative Commons 2.5 -- Attib & Share Alike

Ported to PIC (18F2550) by Ian Lesnet 2009
European version write by Augusto Marinucci 2011

*/
#include <p18f2550.h>
#include <delays.h>
#define irled_dir TRISCbits.TRISC2
#define irled_lat LATCbits.LATC2
#define usrled PORTCbits.RC0
#define usrled_dir TRISCbits.TRISC0

#include "WORLDcodes.h" //include TVBGone code data

const rom unsigned int num_EUcodes = NUM_EU_CODES; //NUM_ELEM(NApowerCodes);
int timer=0;
//These are all the variables we need to 
// slurp down the TVBGONE POWER codes and get 
// the actuall delay values.
static struct _tvbgoneparser{
	unsigned int codecnt;
	unsigned char paircnt;
	unsigned char samplebitcnt;
	unsigned char samplebytecnt;
	unsigned char bittracker;
	unsigned char timetableindex;	
	unsigned int onTime;
	unsigned int offTime;
	unsigned char numpairs;
}tvbg;

 volatile void delayint10US(unsigned int delay);

//
//
// This player uses blocking delays to get the timing just right.
// The PIC18F2550 USB driver requires cooperative multi-tasking, so this won't work with an active USB connection. 
// Actually, the USB connection will stop working if you were to run this code.
//
//
void tvbgonePlayer(void){

	for(tvbg.codecnt=0; tvbg.codecnt<num_EUcodes; tvbg.codecnt++){
/*PORTB=tvbg.codecnt;
	delayint10US(25000);
*/
		//setup indicator LED
		usrled_dir=0;
		usrled=0;
		//setup IR LED pin
        irled_dir=1;
		irled_lat=0;

		//get and set PWM frequency
		if(EUpowerCodes[tvbg.codecnt]->timer_val>0){ //setup PWM with this value
            PR2=EUpowerCodes[tvbg.codecnt]->timer_val; //period
			CCPR1L=(EUpowerCodes[tvbg.codecnt]->timer_val>>1); //50% duty cycle
			CCP1CON = ((CCPR1L & 3) << 4) | 0x0C; //0b00011100;//0b00001100 ; //(5-4 two LSB of duty, 3-0 set PWM)
			T2CON = 0b00000100	 ;//timer and prescalers (pre:x4)
			}else{//some don't use PWM, setup for direct on/off
		T2CON=0;
			CCP1CON=0;
			irled_lat=1;
		}

		//setup the bit tracker and sample counter offset
		tvbg.bittracker=0b10000000;	
		tvbg.samplebytecnt=0;

		//there are numpairs pairs of bitcompression length in *samples that refer to value pairs in *times
		for(tvbg.paircnt=0; tvbg.paircnt<EUpowerCodes[tvbg.codecnt]->numpairs; tvbg.paircnt++){
			
			//get the next index to the the times table values
			tvbg.timetableindex=0;	
			for(tvbg.samplebitcnt=0; tvbg.samplebitcnt<EUpowerCodes[tvbg.codecnt]->bitcompression; tvbg.samplebitcnt++){
				tvbg.timetableindex=(tvbg.timetableindex<<1);
				if((EUpowerCodes[tvbg.codecnt]->samples[tvbg.samplebytecnt] & tvbg.bittracker)!=0) 
					tvbg.timetableindex|=0b1; //set first bit
				tvbg.bittracker=(tvbg.bittracker>>1);
				if(tvbg.bittracker==0){
					tvbg.bittracker=0b10000000;
					tvbg.samplebytecnt++;
				}				
			}
		
			//adjust the index, there are two variables for each entry
			tvbg.timetableindex*=2; //multiply by two, the compiler knows each is an int (2 bytes)

			//PWM for ON time
			irled_dir=0;
			delayint10US(EUpowerCodes[tvbg.codecnt]->times[tvbg.timetableindex]);//on time is first table entry

			//pause PWM for OFF time
		irled_dir=1;
			delayint10US(EUpowerCodes[tvbg.codecnt]->times[(tvbg.timetableindex+1)]);//off time is next entry

		}//for pairs loop
		usrled=1;
delayint10US(1000);//10ms=

		usrled=0;
	
	}//for codes loop
	CCP1CON = 0; //(5-4 two LSB of duty, 3-0 set PWM)
	T2CON = 0;//timer and prescalers (pre:x4)
}

//
//
//	Simple blocking delay using Timer1
//	Polls interrupt to see when 10us have passed, repeats.
//	Hand tune T1_10usOffset in HardwareProfile.h
//
//
//volatile void delayint10US(unsigned int delay);
//#define DELAY 2

volatile void delayint10US(unsigned int delay){
	for(;delay>4;delay--){
    Nop();
		}}


//the hardest part of this project is keeping the pointers straight
//this is a test that shows how to get the actual values from each element
//volatile static unsigned char timer, pairs, bits, sample;
//volatile static unsigned int times;
//timer=NApowerCodes[i]->timer_val;
//pairs=NApowerCodes[i]->numpairs;
//bits=NApowerCodes[i]->bitcompression;
//sample=NApowerCodes[i]->samples[0];
//times=NApowerCodes[i]->times[0];

