/*
This is a simple player for TVBGONE power codes.
Our player is simple because PIC C18 has easy 
reads from program memory. 

This code was written based on the description 
of the data packing method published on the Adafruit 
website. It should be a clean, black-box rewrite, but 
we'll release it as CC 2.5 Attrib & Share Alike 
out of respect for the original authors.

PIC C18 Player (c) Ian Lesnet 2009
for use with IR Toy v1.0 hardware.
http://dangerousprototypes.com

With credits to:

TV-B-Gone Firmware version 1.2
for use with ATtiny85v and v1.2 hardware
(c) Mitch Altman + Limor Fried 2009
Last edits, August 16 2009

With some code from:
Kevin Timmerman & Damien Good 7-Dec-07

Distributed under Creative Commons 2.5 -- Attib & Share Alike

Ported to PIC (18F2550) by Ian Lesnet 2009
European version write by Augusto Marinucci 2011
delaytenus(0) 20 us == delaytenUs(2);
*/
//#include "HardwareProfile.h"

//Codes captured from Generation 3 TV-B-Gone by Limor Fried & Mitch Altman
// table of POWER codes
// ported to PIC C18 by Ian Lesnet
// see modified Perl script (parsegen3.pl)
#define EU_CODES
//#define EU_CODES //Incomplete EU power code files to generate EU power codes for PIC
					// see: http://forums.adafruit.com/viewtopic.php?f=23&t=12883&sid=e48df75eefc5975f4e2d7ce3d63e007a

#define uint8_t unsigned char
#define uint16_t unsigned int
#define freq_to_timerval(x) ((2000000/(unsigned int)x)-1) //this calculates the PR2 PWM value for a 48MHZ pic with 4x prescaler

rom const struct IrCode {
  uint8_t timer_val;
  uint8_t numpairs;
  uint8_t bitcompression;
  uint16_t rom const  *times;
uint8_t   rom const *samples;
};
#define NUM_EU_CODES 138


#ifdef EU_CODES
/*
rom const uint16_t code_eu000Times[]  = {
0,0,
0,0,
0,0,
0,0,
0,0,
0,0,
0,0,
};
*/

rom const uint16_t code_eu000Times[]  = {
	43, 47,
	43, 91,
	43, 8324,
	88, 47,
	133, 133,
	264, 90,
	264, 91,
};


rom const uint8_t code_eu000Samples[] = {
	0xA4,
		0x08,
		0x00,
		0x00,
		0x00,
		0x00,
		0x64,
		0x2C,
		0x40,
		0x80,
		0x00,
		0x00,
		0x00,
		0x06,
		0x41,

};
rom const struct IrCode code_eu000Code  = {
	freq_to_timerval(35714),
	40,		// # of pairs
	3,		// # of bits per index
	code_eu000Times,  
	code_eu000Samples,
	
};
rom const uint16_t code_eu001Times[]  = {
	47, 265,
	51, 54,
	51, 108,
	51, 263,
	51, 2053,
	51, 11647,
	100, 109,
};

rom const uint8_t code_eu001Samples[] = {
	0x04,
		0x92,
		0x49,
		0x26,
		0x35,
		0x89,
		0x24,
		0x9A,
		0xD6,
		0x24,
		0x92,
		0x48,
};

rom const struct IrCode code_eu001Code  = {
	freq_to_timerval(30303),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu001Times,  
	code_eu001Samples,
};
rom const uint16_t code_eu002Times[]  = {
	43, 206,
	46, 204,
	46, 456,
	46, 3488,
};
rom const uint8_t code_eu002Samples[] = {
	0x1A,
		0x56,
		0xA6,
		0xD6,
		0x95,
		0xA9,
		0x90,
};
rom const struct IrCode code_eu002Code  = {
	freq_to_timerval(33333),
	26,		// # of pairs
	2,		// # of bits per index
	code_eu002Times,  
	code_eu002Samples,
};


rom const uint16_t code_eu003Times[]  = {
	58, 60,
	58, 2687,
	118, 60,
	237, 60,
	238, 60,
};
rom const uint8_t code_eu003Samples[] = {
	0x68,
		0x20,
		0x80,
		0x40,
		0x03,
		0x10,
		0x41,
		0x00,
		0x80,
		0x00,
};


rom const struct IrCode code_eu003Code  = {
	freq_to_timerval(38462),
	26,		// # of pairs
	3,		// # of bits per index
	code_eu003Times,
code_eu003Samples,	
	
};// Duplicate IR Code - same as na000


rom const uint16_t code_eu004Times[]  = {
	44, 45,
	44, 131,
	44, 7462,
	346, 176,
	346, 178,
};
rom const uint8_t code_eu004Samples[] = {
		0x60,
		0x80,
		0x00,
		0x00,
		0x00,
		0x08,
		0x00,
		0x00,
		0x00,
		0x20,
		0x00,
		0x00,
		0x04,
		0x12,
		0x48,
		0x04,
		0x12,
		0x48,
		0x2A,
		0x02,
		0x00,
		0x00,
		0x00,
		0x00,
		0x20,
		0x00,
		0x00,
		0x00,
		0x80,
		0x00,
		0x00,
		0x10,
		0x49,
		0x20,
		0x10,
		0x49,
		0x20,
		0x80,

};
rom const struct IrCode code_eu004Code  = {
	freq_to_timerval(37037),
	100,		// # of pairs
	3,		// # of bits per index
	code_eu004Times,  
code_eu004Samples,
};// Duplicate IR Code? Similar to NA002


rom const uint16_t code_eu005Times[]  = {
	24, 190,
	25, 80,
	25, 190,
	25, 4199,
	25, 4799,
};
rom const uint8_t code_eu005Samples[] = {
	0x04,
		0x92,
		0x52,
		0x28,
		0x92,
		0x8C,
		0x44,
		0x92,
		0x89,
		0x45,
		0x24,
		0x53,
		0x44,
		0x92,
		0x52,
		0x28,
		0x92,
		0x8C,
		0x44,
		0x92,
		0x89,
		0x45,
		0x24,
		0x51,
};
rom const struct IrCode code_eu005Code  = {
	freq_to_timerval(38610),
	64,		// # of pairs
	3,		// # of bits per index
	code_eu005Times,  
	code_eu005Samples,
};
rom const uint16_t code_eu006Times[]  = {
	53, 63,
	53, 172,
	53, 4472,
	50, 0,
	455, 468,
};
rom const uint8_t code_eu006Samples[] = {
	
		0x84,
		0x90,
		0x00,
		0x04,
		0x90,
		0x00,
		0x00,
		0x80,
		0x00,
		0x04,
		0x12,
		0x49,
		0x2A,
		0x12,
		0x40,
		0x00,
		0x12,
		0x40,
		0x00,
		0x02,
		0x00,
		0x00,
		0x10,
		0x49,
		0x24,
		0xB0,
};
rom const struct IrCode code_eu006Code  = {
	freq_to_timerval(38462),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu006Times,  
	code_eu006Samples,
};
rom const uint16_t code_eu007Times[]  = {
	50, 54,
	50, 159,
	50, 2307,
	838, 422,
};
rom const uint8_t code_eu007Samples[] = {
		0xD4,
		0x00,
		0x15,
		0x10,
		0x25,
		0x00,
		0x05,
		0x44,
		0x09,
		0x40,
		0x01,
		0x51,
		0x01,
};
rom const struct IrCode code_eu007Code  = {
	freq_to_timerval(38462),
	52,		// # of pairs
	2,		// # of bits per index
	code_eu007Times,  
	 code_eu007Samples,	
};// Duplicate IR Code? - Similar to NA010



rom const uint16_t code_eu008Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu008Samples[] = {
			0xA0,
		0x00,
		0x41,
		0x04,
		0x92,
		0x08,
		0x24,
		0x90,
		0x40,
		0x00,
		0x02,
		0x09,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu008Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu008Times,  
	code_eu008Samples,
};



rom const uint16_t code_eu009Times[]  = {
	88, 90,
	88, 91,
	88, 181,
	88, 8976,
	177, 91,
};
rom const uint8_t code_eu009Samples[] = {
	0x10,
		0x92,
		0x49,
		0x46,
		0x33,
		0x09,
		0x24,
		0x94,
		0x60,
};

rom const struct IrCode code_eu009Code  = {
	freq_to_timerval(35714),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu009Times,  
	code_eu009Samples,
};// Duplicate IR Code - same as na005




rom const uint16_t code_eu010Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu010Samples[] = {
		0xA0,
		0x00,
		0x01,
		0x04,
		0x92,
		0x48,
		0x20,
		0x80,
		0x40,
		0x04,
		0x12,
		0x09,
		0x2B,
		0x3D,
		0x00,
};

rom const struct IrCode code_eu010Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu010Times,  
	 code_eu010Samples,
};// Duplicate IR Code - same as NA004



rom const uint16_t code_eu011Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu011Samples[] = {
		0x84,
		0x00,
		0x48,
		0x04,
		0x02,
		0x01,
		0x04,
		0x80,
		0x09,
		0x00,
		0x12,
		0x40,
		0x2A,
		0xBA,
		0x40,
};
rom const struct IrCode code_eu011Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu011Times,  
	code_eu011Samples,
};
rom const uint16_t code_eu012Times[]  = {
	46, 206,
	46, 459,
	46, 3447,
};
rom const uint8_t code_eu012Samples[] = {
		0x05,
		0x01,
		0x51,
		0x81,
		0x40,
		0x54,
		0x40,
};
rom const struct IrCode code_eu012Code  = {
	freq_to_timerval(33445),
	26,		// # of pairs
	2,		// # of bits per index
	code_eu012Times,  
	code_eu012Samples,
};
rom const uint16_t code_eu013Times[]  = {
	53, 59,
	53, 171,
	53, 2302,
	895, 449,
};
rom const uint8_t code_eu013Samples[] = {
			0xD4,
		0x55,
		0x00,
		0x00,
		0x40,
		0x15,
		0x54,
		0x00,
		0x01,
		0x55,
		0x56,
		0xD4,
		0x55,
		0x00,
		0x00,
		0x40,
		0x15,
		0x54,
		0x00,
		0x01,
		0x55,
		0x55,
};
rom const struct IrCode code_eu013Code  = {
	freq_to_timerval(38462),
	88,		// # of pairs
	2,		// # of bits per index
	code_eu013Times,  
	code_eu013Samples,	
};


rom const uint16_t code_eu014Times[]  = {
	48, 52,
	48, 160,
	48, 400,
	48, 2335,
	799, 400,
};
rom const uint8_t code_eu014Samples[] = {
	
		0x80,
		0x10,
		0x40,
		0x08,
		0x82,
		0x08,
		0x01,
		0xC0,
		0x08,
		0x20,
		0x04,
		0x41,
		0x04,
		0x00,
		0x00,
	};


rom const struct IrCode code_eu014Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu014Times,  
	code_eu014Samples,
	};// Duplicate IR Code - same as NA021


rom const uint16_t code_eu015Times[]  = {
	53, 54,
	53, 156,
	53, 2542,
	851, 425,
	853, 424,
};
rom const uint8_t code_eu015Samples[] = {
	0x60,
		0x82,
		0x08,
		0x24,
		0x10,
		0x41,
		0x00,
		0x12,
		0x40,
		0x04,
		0x80,
		0x09,
		0x2A,
		0x02,
		0x08,
		0x20,
		0x90,
		0x41,
		0x04,
		0x00,
		0x49,
		0x00,
		0x12,
		0x00,
		0x24,
		0xA8,
		0x08,
		0x20,
		0x82,
		0x41,
		0x04,
		0x10,
		0x01,
		0x24,
		0x00,
		0x48,
		0x00,
		0x92,
		0xA0,
		0x20,
		0x82,
		0x09,
		0x04,
		0x10,
		0x40,
		0x04,
		0x90,
		0x01,
		0x20,
		0x02,
		0x48,
};
rom const struct IrCode code_eu015Code  = {
	freq_to_timerval(38462),
	136,		// # of pairs
	3,		// # of bits per index
	code_eu015Times,  
	code_eu015Samples,
};// Duplicate IR Code? - Similar to NA018

rom const uint16_t code_eu016Times[]  = {
	28, 92,
	28, 213,
	28, 214,
	28, 2771,
};
rom const uint8_t code_eu016Samples[] = {
		0x68,
		0x08,
		0x20,
		0x00,
		0xEA,
		0x02,
		0x08,
		0x00,
		0x10,
};
rom const struct IrCode code_eu016Code  = {
	freq_to_timerval(33333),
	34,		// # of pairs
	2,		// # of bits per index
	code_eu016Times,  
	code_eu016Samples
};
rom const uint16_t code_eu017Times[]  = {
	15, 844,
	16, 557,
	16, 844,
	16, 5224,
};
rom const uint8_t code_eu017Samples[] = {
		0x1A,
		0x9A,
		0x9B,
		0x9A,
		0x9A,
		0x99,
};
rom const struct IrCode code_eu017Code  = {
	freq_to_timerval(33333),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu017Times,  
	code_eu017Samples,
};


rom const uint16_t code_eu018Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu018Samples[] = {
		0xA0,
		0x02,
		0x48,
		0x04,
		0x90,
		0x01,
		0x20,
		0x12,
		0x40,
		0x04,
		0x80,
		0x09,
		0x2B,
		0x3D,
		0x00,
};

rom const struct IrCode code_eu018Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu018Times,  
	 code_eu018Samples,
};
rom const uint16_t code_eu019Times[]  = {
	50, 54,
	50, 158,
	50, 418,
	50, 2443,
	843, 418,
};
rom const uint8_t code_eu019Samples[] = {
			0x80,
		0x80,
		0x00,
		0x08,
		0x12,
		0x40,
		0x01,
		0xC0,
		0x40,
		0x00,
		0x04,
		0x09,
		0x20,
		0x00,
		0x00,
};
rom const struct IrCode code_eu019Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu019Times,  
	code_eu019Samples,
};
rom const uint16_t code_eu020Times[]  = {
	48, 301,
	48, 651,
	48, 1001,
	48, 3001,
};
rom const uint8_t code_eu020Samples[] = {
	0x22,
		0x20,
		0x00,
		0x01,
		0xC8,
		0x88,
		0x00,
		0x00,
		0x40,
};
rom const struct IrCode code_eu020Code  = {
	freq_to_timerval(35714),
	34,		// # of pairs
	2,		// # of bits per index
	code_eu020Times,  
	 code_eu020Samples,
};


rom const uint16_t code_eu021Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu021Samples[] = {
		0x84,
		0x80,
		0x00,
		0x20,
		0x82,
		0x49,
		0x00,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2A,
		0xBA,
		0x40,
};
rom const struct IrCode code_eu021Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu021Times,  
	code_eu021Samples,
};


rom const uint16_t code_eu022Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu022Samples[] = {
		0xA4,
		0x80,
		0x41,
		0x00,
		0x12,
		0x08,
		0x24,
		0x90,
		0x40,
		0x00,
		0x02,
		0x09,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu022Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu022Times,  
    code_eu022Samples,
};


rom const uint16_t code_eu023Times[]  = {
	53, 60,
	53, 175,
	53, 4463,
	53, 9453,
	892, 450,
	895, 225,
};
rom const uint8_t code_eu023Samples[] = {
		0x80,
		0x02,
		0x40,
		0x00,
		0x02,
		0x40,
		0x00,
		0x00,
		0x01,
		0x24,
		0x92,
		0x48,
		0x0A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu023Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu023Times,  
	code_eu023Samples,
};// Duplicate IR Code - Same as NA022




rom const uint16_t code_eu024Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu024Samples[] = {
		0xA0,
		0x02,
		0x48,
		0x04,
		0x90,
		0x01,
		0x20,
		0x00,
		0x40,
		0x04,
		0x92,
		0x09,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu024Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu024Times,  
	code_eu024Samples,
};
rom const uint16_t code_eu025Times[]  = {
	49, 52,
	49, 102,
	49, 250,
	49, 252,
	49, 2377,
	49, 12009,
	100, 52,
	100, 102,
};
rom const uint8_t code_eu025Samples[] = {
	0x47,
		0x00,
		0x23,
		0x3C,
		0x01,
		0x59,
		0xE0,
		0x04,
};
rom const struct IrCode code_eu025Code  = {
	freq_to_timerval(31250),
	21,		// # of pairs
	3,		// # of bits per index
	code_eu025Times,  
	code_eu025Samples,
};
rom const uint16_t code_eu026Times[]  = {
	14, 491,
	14, 743,
	14, 4926,
};
rom const uint8_t code_eu026Samples[] = {
	0x55,
		0x40,
		0x42,
		0x55,
		0x40,
		0x41,
};
rom const struct IrCode code_eu026Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu026Times,  
	code_eu026Samples,
};


rom const uint16_t code_eu027Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu027Samples[] = {
		0xA0,
		0x82,
		0x08,
		0x24,
		0x10,
		0x41,
		0x04,
		0x10,
		0x01,
		0x20,
		0x82,
		0x48,
		0x0B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu027Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu027Times,  
code_eu027Samples,
};
rom const uint16_t code_eu028Times[]  = {
	47, 267,
	50, 55,
	50, 110,
	50, 265,
	50, 2055,
	50, 12117,
	100, 57,
};
rom const uint8_t code_eu028Samples[] = {
	0x04,
		0x92,
		0x49,
		0x26,
		0x34,
		0x72,
		0x24,
		0x9A,
		0xD1,
		0xC8,
		0x92,
		0x48,
};

rom const struct IrCode code_eu028Code  = {
	freq_to_timerval(30303),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu028Times,  
	code_eu028Samples,
};
rom const uint16_t code_eu029Times[]  = {
	50, 50,
	50, 99,
	50, 251,
	50, 252,
	50, 1445,
	50, 11014,
	102, 49,
	102, 98,
};
rom const uint8_t code_eu029Samples[] = {
			0x47,
		0x00,
		0x00,
		0x00,
		0x00,
		0x04,
		0x64,
		0x62,
		0x00,
		0xE0,
		0x00,
		0x2B,
		0x23,
		0x10,
		0x07,
		0x00,
		0x00,
		0x80,
};
rom const struct IrCode code_eu029Code  = {
	freq_to_timerval(34483),
	46,		// # of pairs
	3,		// # of bits per index
	code_eu029Times,  
	code_eu029Samples,
};


rom const uint16_t code_eu030Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu030Samples[] = {
		0xA0,
		0x10,
		0x00,
		0x04,
		0x82,
		0x49,
		0x20,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu030Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu030Times,  
	code_eu030Samples,
};// Duplicate IR Code? - Smilar to NA020

rom const uint16_t code_eu031Times[]  = {
	53, 53,
	53, 160,
	53, 1697,
	838, 422,
};
rom const uint8_t code_eu031Samples[] = {
		0xD5,
		0x50,
		0x15,
		0x11,
		0x65,
		0x54,
		0x05,
		0x44,
		0x59,
		0x55,
		0x01,
		0x51,
		0x15,
};

rom const struct IrCode code_eu031Code  = {
	freq_to_timerval(38462),
	52,		// # of pairs
	2,		// # of bits per index
	code_eu031Times,  
	code_eu031Samples,
};
rom const uint16_t code_eu032Times[]  = {
	49, 205,
	49, 206,
	49, 456,
	49, 3690,
};
rom const uint8_t code_eu032Samples[] = {
	0x1A,
		0x56,
		0xA5,
		0xD6,
		0x95,
		0xA9,
		0x40,
};
rom const struct IrCode code_eu032Code  = {
	freq_to_timerval(33333),
	26,		// # of pairs
	2,		// # of bits per index
	code_eu032Times,  
	code_eu032Samples,
};
rom const uint16_t code_eu033Times[]  = {
	48, 150,
	50, 149,
	50, 347,
	50, 2936,
};
rom const uint8_t code_eu033Samples[] = {
		0x2A,
		0x5D,
		0xA9,
		0x60,
};
rom const struct IrCode code_eu033Code  = {
	freq_to_timerval(38462),
	14,		// # of pairs
	2,		// # of bits per index
	code_eu033Times,  
	code_eu033Samples,
};



rom const uint16_t code_eu034Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu034Samples[] = {
			0xA0,
		0x02,
		0x40,
		0x04,
		0x90,
		0x09,
		0x20,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu034Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu034Times,  
	code_eu034Samples,
};


rom const uint16_t code_eu035Times[]  = {
	88, 90,
	88, 91,
	88, 181,
	88, 8976,
	177, 91,
};
rom const uint8_t code_eu035Samples[] = {
			0x10,
		0x92,
		0x49,
		0x46,
		0x33,
		0x09,
		0x24,
		0x94,
		0x60,
};
rom const struct IrCode code_eu035Code  = {
	freq_to_timerval(35714),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu035Times,  
	code_eu035Samples,
};// Duplicate IR Code - same as eu009!



rom const uint16_t code_eu036Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu036Samples[] = {
		0xA4,
		0x00,
		0x49,
		0x00,
		0x92,
		0x00,
		0x20,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu036Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu036Times,  
	code_eu036Samples,
};
rom const uint16_t code_eu037Times[]  = {
	14, 491,
	14, 743,
	14, 5178,
};
rom const uint8_t code_eu037Samples[] = {
		0x45,
		0x50,
		0x02,
		0x45,
		0x50,
		0x01,
};
rom const struct IrCode code_eu037Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu037Times,  
code_eu037Samples,
};
rom const uint16_t code_eu038Times[]  = {
	3, 1002,
	3, 1495,
	3, 3059,
};
rom const uint8_t code_eu038Samples[] = {
	0x05,
		0x60,
		0x54,	
};
rom const struct IrCode code_eu038Code  = {
	0,              // Non-pulsed code
	11,		// # of pairs
	2,		// # of bits per index
	code_eu038Times,  
	code_eu038Samples,
};
rom const uint16_t code_eu039Times[]  = {
	13, 445,
	13, 674,
	13, 675,
	13, 4583,
};
rom const uint8_t code_eu039Samples[] = {
		0x6A,
		0x82,
		0x83,
		0xAA,
		0x82,
		0x81,
};
rom const struct IrCode code_eu039Code  = {
	freq_to_timerval(40161),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu039Times,  
	code_eu039Samples,
};
rom const uint16_t code_eu040Times[]  = {
	85, 89,
	85, 264,
	85, 3402,
	347, 350,
	348, 350,
};
rom const uint8_t code_eu040Samples[] = {
		0x60,
		0x90,
		0x40,
		0x20,
		0x80,
		0x40,
		0x20,
		0x90,
		0x41,
		0x2A,
		0x02,
		0x41,
		0x00,
		0x82,
		0x01,
		0x00,
		0x82,
		0x41,
		0x04,
		0x80,
};
rom const struct IrCode code_eu040Code  = {
	freq_to_timerval(35714),
	52,		// # of pairs
	3,		// # of bits per index
	code_eu040Times,  
	code_eu040Samples,
};
rom const uint16_t code_eu041Times[]  = {
	46, 300,
	49, 298,
	49, 648,
	49, 997,
	49, 3056,
};
rom const uint8_t code_eu041Samples[] = {
		0x0C,
		0xB2,
		0xCA,
		0x49,
		0x13,
		0x0B,
		0x2C,
		0xB2,
		0x92,
		0x44,
		0xB0,
};
rom const struct IrCode code_eu041Code  = {
	freq_to_timerval(33333),
	28,		// # of pairs
	3,		// # of bits per index
	code_eu041Times,  
	code_eu041Samples,
};


rom const uint16_t code_eu042Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu042Samples[] = {
		0x80,
		0x00,
		0x00,
		0x24,
		0x92,
		0x09,
		0x00,
		0x82,
		0x00,
		0x04,
		0x10,
		0x49,
		0x2A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu042Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu042Times,  
code_eu042Samples,
};
rom const uint16_t code_eu043Times[]  = {
	1037, 4216,
	1038, 0,
};
rom const uint8_t code_eu043Samples[] = {
		0x10,
};
rom const struct IrCode code_eu043Code  = {
	freq_to_timerval(41667),
	2,		// # of pairs
	2,		// # of bits per index
	code_eu043Times,  
	code_eu043Samples,
};


rom const uint16_t code_eu044Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu044Samples[] = {
		0xA0,
		0x02,
		0x01,
		0x04,
		0x90,
		0x48,
		0x20,
		0x00,
		0x00,
		0x04,
		0x92,
		0x49,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu044Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu044Times,  
code_eu044Samples,
};
rom const uint16_t code_eu045Times[]  = {
	152, 471,
	154, 156,
	154, 469,
	154, 2947,
};
rom const uint8_t code_eu045Samples[] = {
		0x16,
		0xE5,
		0x90,
};
rom const struct IrCode code_eu045Code  = {
	freq_to_timerval(41667),
	10,		// # of pairs
	2,		// # of bits per index
	code_eu045Times,  
	code_eu045Samples,
};
rom const uint16_t code_eu046Times[]  = {
	15, 493,
	16, 493,
	16, 698,
	16, 1414,
};
rom const uint8_t code_eu46Samples[] = {
		0x16,
		0xAB,
		0x56,
		0xA9,
};
rom const struct IrCode code_eu046Code  = {
	freq_to_timerval(34602),
	16,		// # of pairs
	2,		// # of bits per index
	code_eu046Times,  
	code_eu46Samples,
};
rom const uint16_t code_eu047Times[]  = {
	3, 496,
	3, 745,
	3, 1488,
};
rom const uint8_t code_eu047Samples[] = {
			0x41,
		0x24,
		0x12,
		0x41,
		0x00,
};
rom const struct IrCode code_eu047Code  = {
	0,              // Non-pulsed code
	17,		// # of pairs
	2,		// # of bits per index
	code_eu047Times,  
	code_eu047Samples,
};


rom const uint16_t code_eu048Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu048Samples[] = {
			0x80,
		0x00,
		0x00,
		0x24,
		0x82,
		0x49,
		0x04,
		0x80,
		0x40,
		0x00,
		0x12,
		0x09,
		0x2A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu048Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu048Times,  
code_eu048Samples,
};
rom const uint16_t code_eu049Times[]  = {
	55, 55,
	55, 167,
	55, 4577,
	55, 9506,
	448, 445,
	450, 444,
};
rom const uint8_t code_eu049Samples[] = {
		0x80,
		0x92,
		0x00,
		0x00,
		0x92,
		0x00,
		0x00,
		0x10,
		0x40,
		0x04,
		0x82,
		0x09,
		0x2A,
		0x97,
		0x48,
};
rom const struct IrCode code_eu049Code  = {
	freq_to_timerval(38462),
	40,		// # of pairs
	3,		// # of bits per index
	code_eu049Times,  
code_eu049Samples,
};
rom const uint16_t code_eu050Times[]  = {
	91, 88,
	91, 267,
	91, 3621,
	361, 358,
	361, 359,
};
rom const uint8_t code_eu050Samples[] = {
	0x60,
		0x00,
		0x00,
		0x00,
		0x12,
		0x49,
		0x24,
		0x92,
		0x42,
		0x80,
		0x00,
		0x00,
		0x00,
		0x12,
		0x49,
		0x24,
		0x92,
		0x40,
};
rom const struct IrCode code_eu050Code  = {
	freq_to_timerval(33333),
	48,		// # of pairs
	3,		// # of bits per index
	code_eu050Times,  
	code_eu050Samples,
};
rom const uint16_t code_eu051Times[]  = {
	84, 88,
	84, 261,
	84, 3360,
	347, 347,
	347, 348,
};
rom const uint8_t code_eu051Samples[] = {
		0x60,
		0x82,
		0x00,
		0x20,
		0x80,
		0x41,
		0x04,
		0x90,
		0x41,
		0x2A,
		0x02,
		0x08,
		0x00,
		0x82,
		0x01,
		0x04,
		0x12,
		0x41,
		0x04,
		0x80,
};
rom const struct IrCode code_eu051Code  = {
	freq_to_timerval(38462),
	52,		// # of pairs
	3,		// # of bits per index
	code_eu051Times,  
	code_eu051Samples,
};// Duplicate IR Code? - Similar to NA115

rom const uint16_t code_eu052Times[]  = {
	16, 838,
	17, 558,
	17, 839,
	17, 6328,
};
rom const uint8_t code_eu052Samples[] = {
		0x1A,
		0x9A,
		0x9B,
		0x9A,
		0x9A,
		0x99,
};
rom const struct IrCode code_eu052Code  = {
	freq_to_timerval(31250),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu052Times,  
	code_eu052Samples,
};// Duplicate IR Code? -  Similar to EU017


/* Duplicate timing table, same as eu046 !
rom const uint16_t code_eu053Times[]  = {
	15, 493,
	16, 493,
	16, 698,
	16, 1414,
};
*/
rom const uint8_t code_eu053Samples[] = {
	0x26,
		0xAB,
		0x66,
		0xAA,
};
rom const struct IrCode code_eu053Code  = {
	freq_to_timerval(34483),
	16,		// # of pairs
	2,		// # of bits per index
	code_eu046Times,  
	code_eu053Samples,
};
rom const uint16_t code_eu054Times[]  = {
	49, 53,
	49, 104,
	49, 262,
	49, 264,
	49, 8030,
	100, 103,
};
rom const uint8_t code_eu054Samples[] = {
		0x40,
		0x1A,
		0x23,
		0x00,
		0xD0,
		0x80,
};
rom const struct IrCode code_eu054Code  = {
	freq_to_timerval(31250),
	14,		// # of pairs
	3,		// # of bits per index
	code_eu054Times,  
	code_eu054Samples,
};


rom const uint16_t code_eu055Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu055Samples[] = {
		0x80,
		0x00,
		0x00,
		0x20,
		0x92,
		0x49,
		0x00,
		0x02,
		0x40,
		0x04,
		0x90,
		0x09,
		0x2A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu055Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu055Times,  
	code_eu055Samples,
};
rom const uint16_t code_eu056Times[]  = {
	112, 107,
	113, 107,
	677, 2766,
};
rom const uint8_t code_eu056Samples[] = {
	0x26,
};
rom const struct IrCode code_eu056Code  = {
	freq_to_timerval(38462),
	4,		// # of pairs
	2,		// # of bits per index
	code_eu056Times,  
	code_eu056Samples,
};


rom const uint16_t code_eu057Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu057Samples[] = {
		0xA0,
		0x00,
		0x41,
		0x04,
		0x92,
		0x08,
		0x20,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2B,
		0x3D,
		0x00,
};
rom const struct IrCode code_eu057Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu057Times,  
	code_eu057Samples,
}; // Duplicate IR code - same as EU008


rom const uint16_t code_eu058Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu058Samples[] = {
		0x80,
		0x00,
		0x00,
		0x24,
		0x10,
		0x49,
		0x00,
		0x82,
		0x00,
		0x04,
		0x10,
		0x49,
		0x2A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu058Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu058Times,  
	code_eu058Samples,
};
rom const uint16_t code_eu059Times[]  = {
	310, 613,
	310, 614,
	622, 8312,
};
rom const uint8_t code_eu059Samples[] = {
	0x26,
};
rom const struct IrCode code_eu059Code  = {
	freq_to_timerval(41667),
	4,		// # of pairs
	2,		// # of bits per index
	code_eu059Times,  
	code_eu059Samples,
};// Duplicate IR Code? - Similar to EU056

rom const uint16_t code_eu060Times[]  = {
	50, 158,
	53, 51,
	53, 156,
	53, 2180,
};
rom const uint8_t code_eu060Samples[] = {
		0x25,
		0x59,
		0x9A,
		0x5A,
		0xE9,
		0x56,
		0x66,
		0x96,
		0xA0,
};
rom const struct IrCode code_eu060Code  = {
	freq_to_timerval(38462),
	34,		// # of pairs
	2,		// # of bits per index
	code_eu060Times,  
	code_eu060Samples,
};


rom const uint16_t code_eu061Times[]  = {
	88, 90,
	88, 91,
	88, 181,
	88, 8976,
	177, 91,
};
rom const uint8_t code_eu061Samples[] = {
		0x10,
		0x92,
		0x54,
		0x24,
		0xB3,
		0x09,
		0x25,
		0x42,
		0x48,
};
rom const struct IrCode code_eu061Code  = {
	freq_to_timerval(35714),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu061Times,  
	code_eu061Samples,
};
rom const uint8_t code_eu062Samples[] = {
		0x25,
		0x99,
		0x9A,
		0x5A,
		0xE9,
		0x66,
		0x66,
		0x96,
		0xA0,
};
/* Duplicate timing table, same as eu060 !
rom const uint16_t code_eu062Times[]  = {
	50, 158,
	53, 51,
	53, 156,
	53, 2180,
};
*/
rom const struct IrCode code_eu062Code  = {
	freq_to_timerval(38462),
	34,		// # of pairs
	2,		// # of bits per index
	code_eu060Times,  
code_eu062Samples,
};


rom const uint16_t code_eu063Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu063Samples[] = {
		0x80,
		0x00,
		0x00,
		0x24,
		0x90,
		0x41,
		0x00,
		0x82,
		0x00,
		0x04,
		0x10,
		0x49,
		0x2A,
		0xBA,
		0x00,
};
rom const struct IrCode code_eu063Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu063Times,  
	code_eu063Samples,
};
rom const uint16_t code_eu064Times[]  = {
	47, 267,
	50, 55,
	50, 110,
	50, 265,
	50, 2055,
	50, 12117,
	100, 57,
	100, 112,
};
rom const uint8_t code_eu064Samples[] = {
		0x04,
		0x92,
		0x49,
		0x26,
		0x32,
		0x51,
		0xCB,
		0xD6,
		0x4A,
		0x39,
		0x72,
};
rom const struct IrCode code_eu064Code  = {
	freq_to_timerval(30395),
	29,		// # of pairs
	3,		// # of bits per index
	code_eu064Times,  
	code_eu064Samples,
};
rom const uint16_t code_eu065Times[]  = {
	47, 267,
	50, 55,
	50, 110,
	50, 265,
	50, 2055,
	50, 12117,
	100, 112,
};
rom const uint8_t code_eu065Samples[] = {
		0x04,
		0x92,
		0x49,
		0x26,
		0x32,
		0x4A,
		0x38,
		0x9A,
		0xC9,
		0x28,
		0xE2,
		0x48,
};
rom const struct IrCode code_eu065Code  = {
	freq_to_timerval(30303),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu065Times,  
	code_eu065Samples,
};

/* Duplicate timing table, same as eu049 !
rom const uint16_t code_eu066Times[]  = {
	55, 55,
	55, 167,
	55, 4577,
	55, 9506,
	448, 445,
	450, 444,
};
*/
rom const uint8_t code_eu066Samples[] = {
			0x84,
		0x82,
		0x00,
		0x04,
		0x82,
		0x00,
		0x00,
		0x82,
		0x00,
		0x04,
		0x10,
		0x49,
		0x2A,
		0x87,
		0x41,
};
rom const struct IrCode code_eu066Code  = {
	freq_to_timerval(38462),
	40,		// # of pairs
	3,		// # of bits per index
	code_eu049Times,  
code_eu066Samples,
};
rom const uint16_t code_eu067Times[]  = {
	94, 473,
	94, 728,
	102, 1637,
};
rom const uint8_t code_eu067Samples[] = {
	0x41,
		0x24,
		0x12,
};
rom const struct IrCode code_eu067Code  = {
	freq_to_timerval(38462),
	12,		// # of pairs
	2,		// # of bits per index
	code_eu067Times,  
	code_eu067Samples,
};
rom const uint16_t code_eu068Times[]  = {
	49, 263,
	50, 54,
	50, 108,
	50, 263,
	50, 2029,
	50, 10199,
	100, 110,
};
rom const uint8_t code_eu068Samples[] = {
		0x04,
		0x92,
		0x49,
		0x26,
		0x34,
		0x49,
		0x38,
		0x9A,
		0xD1,
		0x24,
		0xE2,
		0x48,
};
rom const struct IrCode code_eu068Code  = {
	freq_to_timerval(38610),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu068Times,  
	code_eu068Samples,
};
rom const uint16_t code_eu069Times[]  = {
	4, 499,
	4, 750,
	4, 4999,
};
rom const uint8_t code_eu069Samples[] = {
		0x05,
		0x54,
		0x06,
		0x05,
		0x54,
		0x04,
};
rom const struct IrCode code_eu069Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu069Times,  
	code_eu069Samples,
};

/* Duplicate timing table, same as eu069 !
rom const uint16_t code_eu070Times[]  = {
	4, 499,
	4, 750,
	4, 4999,
};
*/
rom const uint8_t code_eu070Samples[] = {
		0x14,
		0x54,
		0x06,
		0x14,
		0x54,
		0x04,
};
rom const struct IrCode code_eu070Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu069Times,  
	code_eu070Samples,
};
rom const uint16_t code_eu071Times[]  = {
	14, 491,
	14, 743,
	14, 4422,
};
rom const uint8_t code_eu071Samples[] = {
		0x45,
		0x44,
		0x56,
		0x45,
		0x44,
		0x55,
};
rom const struct IrCode code_eu071Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu071Times,  
	code_eu071Samples,
};
rom const uint16_t code_eu072Times[]  = {
	5, 568,
	5, 854,
	5, 4999,
};
rom const uint8_t code_eu072Samples[] = {
		0x55,
		0x45,
		0x46,
		0x55,
		0x45,
		0x44,
};
rom const struct IrCode code_eu072Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu072Times,  
	code_eu072Samples,
};

/* Duplicate timing table, same as eu046 !
rom const uint16_t code_eu073Times[]  = {
	15, 493,
	16, 493,
	16, 698,
	16, 1414,
};
*/
rom const uint8_t code_eu073Samples[] = {
		0x19,
		0x57,
		0x59,
		0x55,
};
rom const struct IrCode code_eu073Code  = {
	freq_to_timerval(34483),
	16,		// # of pairs
	2,		// # of bits per index
	code_eu046Times,  
	code_eu073Samples,
};


rom const uint16_t code_eu074Times[]  = {
	88, 89,
	88, 90,
	88, 179,
	88, 8977,
	177, 90,
};
rom const uint8_t code_eu074Samples[] = {
		0x04,
		0x92,
		0x49,
		0x28,
		0xC6,
		0x49,
		0x24,
		0x92,
		0x51,
		0x80,
};

rom const struct IrCode code_eu074Code  = {
	freq_to_timerval(35714),
	26,		// # of pairs
	3,		// # of bits per index
	code_eu047Times,  
	code_eu074Samples,
};
rom const uint16_t code_eu075Times[]  = {
	6, 566,
	6, 851,
	6, 5474,
};
rom const uint8_t code_eu075Samples[] = {
		0x05,
		0x45,
		0x46,
		0x05,
		0x45,
		0x44,
};
rom const struct IrCode code_eu075Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu075Times,  
	code_eu075Samples,
};
rom const uint16_t code_eu076Times[]  = {
	14, 843,
	16, 555,
	16, 841,
	16, 4911,
};
rom const uint8_t code_eu076Samples[] = {
		0x2A,
		0x9A,
		0x9B,
		0xAA,
		0x9A,
		0x9A,
};
rom const struct IrCode code_eu076Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu076Times,  
	code_eu076Samples,
};

/* Duplicate timing table, same as eu028 !
rom const uint16_t code_eu077Times[]  = {
	47, 267,
	50, 55,
	50, 110,
	50, 265,
	50, 2055,
	50, 12117,
	100, 57,
};
*/
rom const uint8_t code_eu077Samples[] = {
			0x04,
		0x92,
		0x49,
		0x26,
		0x32,
		0x51,
		0xC8,
		0x9A,
		0xC9,
		0x47,
		0x22,
		0x48,
};
rom const struct IrCode code_eu077Code  = {
	freq_to_timerval(30303),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu028Times,  
	code_eu077Samples,
};
rom const uint16_t code_eu078Times[]  = {
	6, 925,
	6, 1339,
	6, 2098,
	6, 2787,
};
rom const uint8_t code_eu078Samples[] = {
	0x90,
		0x0D,
		0x00,
};
rom const struct IrCode code_eu078Code  = {
	0,              // Non-pulsed code
	12,		// # of pairs
	2,		// # of bits per index
	code_eu078Times,  
	code_eu078Samples,
};
rom const uint16_t code_eu079Times[]  = {
	53, 59,
	53, 170,
	53, 4359,
	892, 448,
	893, 448,
};
rom const uint8_t code_eu079Samples[] = {
		0x60,
		0x00,
		0x00,
		0x24,
		0x80,
		0x09,
		0x04,
		0x92,
		0x00,
		0x00,
		0x00,
		0x49,
		0x2A,
		0x00,
		0x00,
		0x00,
		0x92,
		0x00,
		0x24,
		0x12,
		0x48,
		0x00,
		0x00,
		0x01,
		0x24,
		0x80,
};
rom const struct IrCode code_eu079Code  = {
	freq_to_timerval(38462),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu079Times,  
	code_eu079Samples,
};
rom const uint16_t code_eu080Times[]  = {
	55, 57,
	55, 167,
	55, 4416,
	895, 448,
	897, 447,
};
rom const uint8_t code_eu080Samples[] = {
		0x60,
		0x00,
		0x00,
		0x20,
		0x10,
		0x09,
		0x04,
		0x02,
		0x01,
		0x00,
		0x90,
		0x48,
		0x2A,
		0x00,
		0x00,
		0x00,
		0x80,
		0x40,
		0x24,
		0x10,
		0x08,
		0x04,
		0x02,
		0x41,
		0x20,
		0x80,
};
rom const struct IrCode code_eu080Code  = {
	freq_to_timerval(38462),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu080Times,  
	code_eu080Samples,
};

rom const uint16_t code_eu081Times[]  = {
	26, 185,
	27, 80,
	27, 185,
	27, 4249,
};
rom const uint8_t code_eu081Samples[] = {
		0x1A,
		0x5A,
		0x65,
		0x67,
		0x9A,
		0x65,
		0x9A,
		0x9B,
		0x9A,
		0x5A,
		0x65,
		0x67,
		0x9A,
		0x65,
		0x9A,
		0x9B,
		0x9A,
		0x5A,
		0x65,
		0x65,
};
rom const struct IrCode code_eu081Code  = {
	freq_to_timerval(38462),
	80,		// # of pairs
	2,		// # of bits per index
	code_eu081Times,  
	code_eu081Samples,
};
rom const uint16_t code_eu082Times[]  = {
	51, 56,
	51, 162,
	51, 2842,
	848, 430,
	850, 429,
};
rom const uint8_t code_eu082Samples[] = {
			0x60,
		0x82,
		0x08,
		0x24,
		0x10,
		0x41,
		0x04,
		0x82,
		0x40,
		0x00,
		0x10,
		0x09,
		0x2A,
		0x02,
		0x08,
		0x20,
		0x90,
		0x41,
		0x04,
		0x12,
		0x09,
		0x00,
		0x00,
		0x40,
		0x24,
		0x80,
};
rom const struct IrCode code_eu082Code  = {
	freq_to_timerval(40000),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu082Times,  
	code_eu082Samples,
};
rom const uint16_t code_eu083Times[]  = {
	16, 559,
	16, 847,
	16, 5900,
	17, 559,
	17, 847,
};
rom const uint8_t code_eu083Samples[] = {
		0x0E,
		0x38,
		0x21,
		0x82,
		0x26,
		0x20,
		0x82,
		0x48,
		0x23,
};
rom const struct IrCode code_eu083Code  = {
	freq_to_timerval(33333),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu083Times,  
	code_eu083Samples,
};
rom const uint16_t code_eu084Times[]  = {
	16, 484,
	16, 738,
	16, 739,
	16, 4795,
};
rom const uint8_t code_eu084Samples[] = {
	0x6A,
		0xA0,
		0x03,
		0xAA,
		0xA0,
		0x01,
};
rom const struct IrCode code_eu084Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu084Times,  
	code_eu084Samples,
};
rom const uint16_t code_eu085Times[]  = {
	48, 52,
	48, 160,
	48, 400,
	48, 2120,
	799, 400,
};
rom const uint8_t code_eu085Samples[] = {
		0x84,
		0x82,
		0x40,
		0x08,
		0x92,
		0x48,
		0x01,
		0xC2,
		0x41,
		0x20,
		0x04,
		0x49,
		0x24,
		0x00,
		0x40,
};
rom const struct IrCode code_eu085Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu085Times,  
	code_eu085Samples,
};
rom const uint16_t code_eu086Times[]  = {
	16, 851,
	17, 554,
	17, 850,
	17, 851,
	17, 4847,
};
rom const uint8_t code_eu086Samples[] = {
	0x45,
		0x86,
		0x5B,
		0x05,
		0xC6,
		0x5B,
		0x05,
		0xB0,
		0x42,
};
rom const struct IrCode code_eu086Code  = {
	freq_to_timerval(33333),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu086Times,  
	code_eu086Samples,
};
rom const uint16_t code_eu087Times[]  = {
	14, 491,
	14, 743,
	14, 5126,
};
rom const uint8_t code_eu087Samples[] = {
	0x55,
		0x50,
		0x02,
		0x55,
		0x50,
		0x01,
};
rom const struct IrCode code_eu087Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu087Times,  
	code_eu087Samples,
};
rom const uint16_t code_eu088Times[]  = {
	14, 491,
	14, 743,
	14, 4874,
};
rom const uint8_t code_eu088Samples[] = {
	0x45,
		0x54,
		0x42,
		0x45,
		0x54,
		0x41,
};
rom const struct IrCode code_eu088Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu088Times,  
	code_eu088Samples,
};


rom const uint16_t code_eu089Times[]  = {
	48, 52,
	48, 160,
	48, 400,
	48, 2335,
	799, 400,
};
rom const uint8_t code_eu089Samples[] = {
		0x84,
		0x10,
		0x40,
		0x08,
		0x82,
		0x08,
		0x01,
		0xC2,
		0x08,
		0x20,
		0x04,
		0x41,
		0x04,
		0x00,
		0x40,
};
rom const struct IrCode code_eu089Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu089Times,  
	code_eu089Samples,
};
rom const uint16_t code_eu090Times[]  = {
	3, 9,
	3, 19,
	3, 29,
	3, 39,
	3, 9968,
};
rom const uint8_t code_eu090Samples[] = {
		0x60,
		0x00,
		0x88,
		0x00,
		0x02,
		0xE3,
		0x00,
		0x04,
		0x40,
		0x00,
		0x16,
};
rom const struct IrCode code_eu090Code  = {
	0,              // Non-pulsed code
	29,		// # of pairs
	3,		// # of bits per index
	code_eu090Times,  
	code_eu090Samples,
};
rom const uint16_t code_eu091Times[]  = {
	15, 138,
	15, 446,
	15, 605,
	15, 6565,
};
rom const uint8_t code_eu091Samples[] = {
	0x80,
		0x01,
		0x00,
		0x2E,
		0x00,
		0x04,
		0x00,
		0xA0,
};
rom const struct IrCode code_eu091Code  = {
	freq_to_timerval(38462),
	30,		// # of pairs
	2,		// # of bits per index
	code_eu091Times,  
	code_eu091Samples,
};
rom const uint16_t code_eu092Times[]  = {
	48, 50,
	48, 148,
	48, 149,
	48, 1424,
};
rom const uint8_t code_eu092Samples[] = {
		0x48,
		0x80,
		0x0E,
		0x22,
		0x00,
		0x10,
};
rom const struct IrCode code_eu092Code  = {
	freq_to_timerval(40000),
	22,		// # of pairs
	2,		// # of bits per index
	code_eu092Times,  
	code_eu092Samples,
};
rom const uint16_t code_eu093Times[]  = {
	87, 639,
	88, 275,
	88, 639,
};
rom const uint8_t code_eu093Samples[] = {
	0x15,
		0x9A,
		0x94,
};
rom const struct IrCode code_eu093Code  = {
	freq_to_timerval(35714),
	11,		// # of pairs
	2,		// # of bits per index
	code_eu093Times,  
	code_eu093Samples,
};
rom const uint16_t code_eu094Times[]  = {
	3, 8,
	3, 18,
	3, 24,
	3, 38,
	3, 9969,
};
rom const uint8_t code_eu094Samples[] = {
		0x60,
		0x80,
		0x88,
		0x00,
		0x00,
		0xE3,
		0x04,
		0x04,
		0x40,
		0x00,
		0x06,
};
rom const struct IrCode code_eu094Code  = {
	0,              // Non-pulsed code
	29,		// # of pairs
	3,		// # of bits per index
	code_eu094Times,  
	code_eu094Samples,
};

/* Duplicate timing table, same as eu046 !
rom const uint16_t code_eu095Times[]  = {
	15, 493,
	16, 493,
	16, 698,
	16, 1414,
};
*/
rom const uint8_t code_eu095Samples[] = {
	0x2A,
		0xAB,
		0x6A,
		0xAA,
};
rom const struct IrCode code_eu095Code  = {
	freq_to_timerval(34483),
	16,		// # of pairs
	2,		// # of bits per index
	code_eu046Times,  
	code_eu095Samples,
};
rom const uint16_t code_eu096Times[]  = {
	13, 608,
	14, 141,
	14, 296,
	14, 451,
	14, 606,
	14, 608,
	14, 6207,
};
rom const uint8_t code_eu096Samples[] = {
	0x04,
		0x94,
		0x4B,
		0x24,
		0x95,
		0x35,
		0x24,
		0xA2,
		0x59,
		0x24,
		0xA8,
		0x40,
};
rom const struct IrCode code_eu096Code  = {
	freq_to_timerval(38462),
	30,		// # of pairs
	3,		// # of bits per index
	code_eu096Times,  
	code_eu096Samples,
};

/* Duplicate timing table, same as eu046 !
rom const uint16_t code_eu097Times[]  = {
	15, 493,
	16, 493,
	16, 698,
	16, 1414,
};
*/
rom const uint8_t code_eu097Samples[] = {
0x19,
		0xAB,
		0x59,
		0xA9,
};
rom const struct IrCode code_eu097Code  = {
	freq_to_timerval(34483),
	16,		// # of pairs
	2,		// # of bits per index
	code_eu046Times,  
	code_eu097Samples,
};
rom const uint16_t code_eu098Times[]  = {
	3, 8,
	3, 18,
	3, 28,
	3, 12731,
};
rom const uint8_t code_eu098Samples[] = {
	0x80,
		0x01,
		0x00,
		0xB8,
		0x55,
		0x10,
		0x08,
};
rom const struct IrCode code_eu098Code  = {
	0,              // Non-pulsed code
	27,		// # of pairs
	2,		// # of bits per index
	code_eu098Times,  
	code_eu098Samples,
};
rom const uint16_t code_eu099Times[]  = {
	46, 53,
	46, 106,
	46, 260,
	46, 1502,
	46, 10962,
	93, 53,
	93, 106,
};
rom const uint8_t code_eu099Samples[] = {
		0x46,
		0x80,
		0x00,
		0x00,
		0x00,
		0x03,
		0x44,
		0x52,
		0x00,
		0x00,
		0x0C,
		0x22,
		0x22,
		0x90,
		0x00,
		0x00,
		0x60,
		0x80,
};
rom const struct IrCode code_eu099Code  = {
	freq_to_timerval(35714),
	46,		// # of pairs
	3,		// # of bits per index
	code_eu099Times,  
	code_eu099Samples,
};


/* Duplicate timing table, same as eu098 !
rom const uint16_t code_eu100Times[]  = {
	3, 8,
	3, 18,
	3, 28,
	3, 12731,
};
*/
rom const uint8_t code_eu100Samples[] = {
		0x80,
		0x04,
		0x00,
		0xB8,
		0x55,
		0x40,
		0x08,
};
rom const struct IrCode code_eu100Code  = {
	0,              // Non-pulsed code
	27,		// # of pairs
	2,		// # of bits per index
	code_eu098Times,  
	code_eu100Samples,
};



rom const uint16_t code_eu101Times[]  = {
	14, 491,
	14, 743,
	14, 4674,
};
rom const uint8_t code_eu101Samples[] = {
	0x55,
		0x50,
		0x06,
		0x55,
		0x50,
		0x05,
};
rom const struct IrCode code_eu101Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu101Times,  
	code_eu101Samples,
};

/* Duplicate timing table, same as eu087 !
rom const uint16_t code_eu102Times[]  = {
	14, 491,
	14, 743,
	14, 5126,
};
*/
rom const uint8_t code_eu102Samples[] = {
	0x45,
		0x54,
		0x02,
		0x45,
		0x54,
		0x01,
};
rom const struct IrCode code_eu102Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu087Times,  
	code_eu102Samples,
};
rom const uint16_t code_eu103Times[]  = {
	44, 815,
	45, 528,
	45, 815,
	45, 5000,
};
rom const uint8_t code_eu103Samples[] = {
	0x29,
		0x9A,
		0x9B,
		0xA9,
		0x9A,
		0x9A,
};
rom const struct IrCode code_eu103Code  = {
	freq_to_timerval(34483),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu103Times,  
	code_eu103Samples,
};
rom const uint16_t code_eu104Times[]  = {
	14, 491,
	14, 743,
	14, 5881,
};
rom const uint8_t code_eu104Samples[] = {
	0x44,
		0x40,
		0x02,
		0x44,
		0x40,
		0x01,
};
rom const struct IrCode code_eu104Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu104Times,  
	code_eu104Samples,
};


rom const uint16_t code_eu105Times[]  = {
	53, 56,
	53, 171,
	53, 3950,
	53, 9599,
	898, 451,
	900, 226,
};
rom const uint8_t code_eu105Samples[] = {
	0x84,
		0x10,
		0x00,
		0x20,
		0x90,
		0x01,
		0x00,
		0x80,
		0x40,
		0x04,
		0x12,
		0x09,
		0x2A,
		0xBA,
		0x40,
};
rom const struct IrCode code_eu105Code  = {
	freq_to_timerval(38610),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu105Times,  
	code_eu105Samples,
};
rom const uint16_t code_eu106Times[]  = {
	48, 246,
	50, 47,
	50, 94,
	50, 245,
	50, 1488,
	50, 10970,
	100, 47,
	100, 94,
};
rom const uint8_t code_eu106Samples[] = {
		0x0B,
		0x12,
		0x49,
		0x24,
		0x92,
		0x49,
		0x8D,
		0x1C,
		0x89,
		0x27,
		0xFC,
		0xAB,
		0x47,
		0x22,
		0x49,
		0xFF,
		0x2A,
		0xD1,
		0xC8,
		0x92,
		0x7F,
		0xC9,
		0x00,
};
rom const struct IrCode code_eu106Code  = {
	freq_to_timerval(38462),
	59,		// # of pairs
	3,		// # of bits per index
	code_eu106Times,  
	code_eu106Samples,
};
rom const uint16_t code_eu107Times[]  = {
	16, 847,
	16, 5900,
	17, 559,
	17, 846,
	17, 847,
};
rom const uint8_t code_eu107Samples[] = {
		0x62,
		0x08,
		0xA0,
		0x8A,
		0x19,
		0x04,
		0x08,
		0x40,
		0x83,
};
rom const struct IrCode code_eu107Code  = {
	freq_to_timerval(33333),
	24,		// # of pairs
	3,		// # of bits per index
	code_eu107Times,  
	code_eu107Samples,
};
rom const uint16_t code_eu108Times[]  = {
	14, 491,
	14, 743,
	14, 4622,
};
rom const uint8_t code_eu108Samples[] = {
	0x45,
		0x54,
		0x16,
		0x45,
		0x54,
		0x15,
};
rom const struct IrCode code_eu108Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu108Times,  
	code_eu108Samples,
};
rom const uint16_t code_eu109Times[]  = {
	24, 185,
	27, 78,
	27, 183,
	27, 1542,
};
rom const uint8_t code_eu109Samples[] = {
	0x19,
		0x95,
		0x5E,
		0x66,
		0x55,
		0x50,
};
rom const struct IrCode code_eu109Code  = {
	freq_to_timerval(38462),
	22,		// # of pairs
	2,		// # of bits per index
	code_eu109Times,  
	code_eu109Samples,
};


rom const uint16_t code_eu110Times[]  = {
	56, 55,
	56, 168,
	56, 4850,
	447, 453,
	448, 453,
};
rom const uint8_t code_eu110Samples[] = {
		0x64,
		0x10,
		0x00,
		0x04,
		0x10,
		0x00,
		0x00,
		0x80,
		0x00,
		0x04,
		0x12,
		0x49,
		0x2A,
		0x10,
		0x40,
		0x00,
		0x10,
		0x40,
		0x00,
		0x02,
		0x00,
		0x00,
		0x10,
		0x49,
		0x24,
		0x90,
};
rom const struct IrCode code_eu110Code  = {
	freq_to_timerval(38462),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu110Times,  
	code_eu110Samples,
};
rom const uint16_t code_eu111Times[]  = {
	49, 52,
	49, 250,
	49, 252,
	49, 2377,
	49, 12009,
	100, 52,
	100, 102,
};
rom const uint8_t code_eu111Samples[] = {
	0x22,
		0x80,
		0x1A,
		0x18,
		0x01,
		0x10,
		0xC0,
		0x02,
};
rom const struct IrCode code_eu111Code  = {
	freq_to_timerval(31250),
	21,		// # of pairs
	3,		// # of bits per index
	code_eu111Times,  
	code_eu111Samples,
};
rom const uint16_t code_eu112Times[]  = {
	55, 55,
	55, 167,
	55, 5023,
	55, 9506,
	448, 445,
	450, 444,
};
rom const uint8_t code_eu112Samples[] = {
		0x80,
		0x02,
		0x00,
		0x00,
		0x02,
		0x00,
		0x04,
		0x92,
		0x00,
		0x00,
		0x00,
		0x49,
		0x2A,
		0x97,
		0x48,
};
rom const struct IrCode code_eu112Code  = {
	freq_to_timerval(38462),
	40,		// # of pairs
	3,		// # of bits per index
	code_eu112Times,  
	code_eu112Samples,
};


/* Duplicate timing table, same as eu054 !
rom const uint16_t code_eu113Times[]  = {
	49, 53,
	49, 104,
	49, 262,
	49, 264,
	49, 8030,
	100, 103,
};
*/
rom const uint8_t code_eu113Samples[] = {
		0x46,
		0x80,
		0x23,
		0x34,
		0x00,
		0x80,
};
rom const struct IrCode code_eu113Code  = {
	freq_to_timerval(31250),
	14,		// # of pairs
	3,		// # of bits per index
	code_eu054Times,  
	code_eu113Samples,
};

/* Duplicate timing table, same as eu028 !
rom const uint16_t code_eu114Times[]  = {
	47, 267,
	50, 55,
	50, 110,
	50, 265,
	50, 2055,
	50, 12117,
	100, 57,
};
*/
rom const uint8_t code_eu114Samples[] = {
			0x04,
		0x92,
		0x49,
		0x26,
		0x34,
		0x71,
		0x44,
		0x9A,
		0xD1,
		0xC5,
		0x12,
		0x48,
};
rom const struct IrCode code_eu114Code  = {
	freq_to_timerval(30303),
	31,		// # of pairs
	3,		// # of bits per index
	code_eu028Times,  
	code_eu114Samples,
};



rom const uint16_t code_eu115Times[]  = {
	48, 98,
	48, 196,
	97, 836,
	395, 388,
	1931, 389,
};
rom const uint8_t code_eu115Samples[] = {
		0x84,
		0x92,
		0x01,
		0x24,
		0x12,
		0x00,
		0x04,
		0x80,
		0x08,
		0x09,
		0x92,
		0x48,
		0x04,
		0x90,
		0x48,
		0x00,
		0x12,
		0x00,
		0x20,
		0x26,
		0x49,
		0x20,
		0x12,
		0x41,
		0x20,
		0x00,
		0x48,
		0x00,
		0x82,
};
rom const struct IrCode code_eu115Code  = {
	freq_to_timerval(58824),
	77,		// # of pairs
	3,		// # of bits per index
	code_eu115Times,  
	code_eu115Samples,
};
rom const uint16_t code_eu116Times[]  = {
	3, 9,
	3, 31,
	3, 42,
	3, 10957,
};
rom const uint8_t code_eu116Samples[] = {
		0x80,
		0x01,
		0x00,
		0x2E,
		0x00,
		0x04,
		0x00,
		0x80,
};
rom const struct IrCode code_eu116Code  = {
	0,              // Non-pulsed code
	29,		// # of pairs
	2,		// # of bits per index
	code_eu116Times,  
	code_eu116Samples,
};
rom const uint16_t code_eu117Times[]  = {
	49, 53,
	49, 262,
	49, 264,
	49, 8030,
	100, 103,
};
rom const uint8_t code_eu117Samples[] = {
	0x22,
		0x00,
		0x1A,
		0x10,
		0x00,
		0x40,
};
rom const struct IrCode code_eu117Code  = {
	freq_to_timerval(31250),
	14,		// # of pairs
	3,		// # of bits per index
	code_eu117Times,  
	code_eu117Samples,
};
rom const uint16_t code_eu118Times[]  = {
	44, 815,
	45, 528,
	45, 815,
	45, 4713,
};
rom const uint8_t code_eu118Samples[] = {
	0x2A,
		0x9A,
		0x9B,
		0xAA,
		0x9A,
		0x9A,
};
rom const struct IrCode code_eu118Code  = {
	freq_to_timerval(34483),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu118Times,  
code_eu118Samples,
};

rom const uint16_t code_eu119Times[]  = {
	14, 491,
	14, 743,
	14, 5430,
};
rom const uint8_t code_eu119Samples[] = {
		0x44,
		0x44,
		0x02,
		0x44,
		0x44,
		0x01,
};
rom const struct IrCode code_eu119Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu119Times,  
	code_eu119Samples,
};


rom const uint16_t code_eu120Times[]  = {
	19, 78,
	21, 27,
	21, 77,
	21, 3785,
	18, 0,
};
rom const uint8_t code_eu120Samples[] = {
		0x09,
		0x24,
		0x92,
		0x49,
		0x12,
		0x4A,
		0x24,
		0x92,
		0x49,
		0x24,
		0x92,
		0x49,
		0x24,
		0x94,
		0x89,
		0x69,
		0x24,
		0x92,
		0x49,
		0x22,
		0x49,
		0x44,
		0x92,
		0x49,
		0x24,
		0x92,
		0x49,
		0x24,
		0x92,
		0x91,
		0x30,
};
rom const struct IrCode code_eu120Code  = {
	freq_to_timerval(38462),
	82,		// # of pairs
	3,		// # of bits per index
	code_eu120Times,  
	code_eu120Samples,
};

/* Duplicate timing table, same as eu051 !
rom const uint16_t code_eu121Times[]  = {
	84, 88,
	84, 261,
	84, 3360,
	347, 347,
	347, 348,
};
*/
rom const uint8_t code_eu121Samples[] = {
		0x64,
		0x00,
		0x09,
		0x24,
		0x00,
		0x09,
		0x24,
		0x00,
		0x09,
		0x2A,
		0x10,
		0x00,
		0x24,
		0x90,
		0x00,
		0x24,
		0x90,
		0x00,
		0x24,
		0x90,
};
rom const struct IrCode code_eu121Code  = {
	freq_to_timerval(38462),
	52,		// # of pairs
	3,		// # of bits per index
	code_eu051Times,  
	code_eu121Samples,
};

/* Duplicate timing table, same as eu120 !
rom const uint16_t code_eu122Times[]  = {
	19, 78,
	21, 27,
	21, 77,
	21, 3785,
	22, 0,
};
*/
rom const uint8_t code_eu122Samples[] = {
			0x04,
		0xA4,
		0x92,
		0x49,
		0x22,
		0x49,
		0x48,
		0x92,
		0x49,
		0x24,
		0x92,
		0x49,
		0x24,
		0x94,
		0x89,
		0x68,
		0x94,
		0x92,
		0x49,
		0x24,
		0x49,
		0x29,
		0x12,
		0x49,
		0x24,
		0x92,
		0x49,
		0x24,
		0x92,
		0x91,
		0x30,
};
rom const struct IrCode code_eu122Code  = {
	freq_to_timerval(38462),
	82,		// # of pairs
	3,		// # of bits per index
	code_eu120Times,  
	code_eu122Samples,
};
rom const uint16_t code_eu123Times[]  = {
	13, 490,
	13, 741,
	13, 742,
	13, 5443,
};
rom const uint8_t code_eu123Samples[] = {
	0x6A,
		0xA0,
		0x0B,
		0xAA,
		0xA0,
		0x09,
};
rom const struct IrCode code_eu123Code  = {
	freq_to_timerval(40000),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu123Times,  
	code_eu123Samples,
};
rom const uint16_t code_eu124Times[]  = {
	50, 54,
	50, 158,
	50, 407,
	50, 2153,
	843, 407,
};
rom const uint8_t code_eu124Samples[] = {
			0x80,
		0x10,
		0x40,
		0x08,
		0x92,
		0x48,
		0x01,
		0xC0,
		0x08,
		0x20,
		0x04,
		0x49,
		0x24,
		0x00,
		0x00,
};
rom const struct IrCode code_eu124Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu124Times,  
	code_eu124Samples,
};
rom const uint16_t code_eu125Times[]  = {
	55, 56,
	55, 168,
	55, 3929,
	52, 0,
	882, 454,
	884, 452,
};
rom const uint8_t code_eu125Samples[] = {
	0x84,
		0x80,
		0x00,
		0x20,
		0x82,
		0x49,
		0x00,
		0x02,
		0x00,
		0x04,
		0x90,
		0x49,
		0x2A,
		0x92,
		0x00,
		0x00,
		0x82,
		0x09,
		0x24,
		0x00,
		0x08,
		0x00,
		0x12,
		0x41,
		0x24,
		0xB0,
};
rom const struct IrCode code_eu125Code  = {
	freq_to_timerval(38462),
	68,		// # of pairs
	3,		// # of bits per index
	code_eu125Times,  
	code_eu125Samples,
};


rom const uint16_t code_eu126Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu126Samples[] = {
		0xA0,
		0x00,
		0x00,
		0x04,
		0x92,
		0x49,
		0x20,
		0x00,
		0x00,
		0x04,
		0x92,
		0x49,
		0x2B,
		0x3D,
		0x00,
};

rom const struct IrCode code_eu126Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu126Times,  
	code_eu126Samples,
};

/* Duplicate timing table, same as eu087 !
rom const uint16_t code_eu127Times[]  = {
	14, 491,
	14, 743,
	14, 5126,
};
*/
rom const uint8_t code_eu127Samples[] = {
		0x44,
		0x40,
		0x56,
		0x44,
		0x40,
		0x55,
};
rom const struct IrCode code_eu127Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu087Times,  
	code_eu127Samples,
};
rom const uint16_t code_eu128Times[]  = {
	152, 471,
	154, 156,
	154, 469,
	154, 782,
	154, 2947,
};
rom const uint8_t code_eu128Samples[] = {
	0x05,
		0xC4,
		0x59,
};
rom const struct IrCode code_eu128Code  = {
	freq_to_timerval(41667),
	8,		// # of pairs
	3,		// # of bits per index
	code_eu128Times,  
	code_eu128Samples,
};
rom const uint16_t code_eu129Times[]  = {
	50, 50,
	50, 99,
	50, 251,
	50, 252,
	50, 1449,
	50, 11014,
	102, 49,
	102, 98,
};
rom const uint8_t code_eu129Samples[] = {
		0x47,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x8C,
		0x8C,
		0x40,
		0x03,
		0xF1,
		0xEB,
		0x23,
		0x10,
		0x00,
		0xFC,
		0x74,
};
rom const struct IrCode code_eu129Code  = {
	freq_to_timerval(38462),
	45,		// # of pairs
	3,		// # of bits per index
	code_eu129Times,  
	code_eu129Samples,
};

/* Duplicate timing table, same as eu129 !
rom const uint16_t code_eu130Times[]  = {
	50, 50,
	50, 99,
	50, 251,
	50, 252,
	50, 1449,
	50, 11014,
	102, 49,
	102, 98,
};
*/
rom const uint8_t code_eu130Samples[] = {
			0x47,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x8C,
		0x8C,
		0x40,
		0x03,
		0xE3,
		0xEB,
		0x23,
		0x10,
		0x00,
		0xF8,
		0xF4,
};
rom const struct IrCode code_eu130Code  = {
	freq_to_timerval(38462),
	45,		// # of pairs
	3,		// # of bits per index
	code_eu129Times,  
	code_eu130Samples,
};
rom const uint16_t code_eu131Times[]  = {
	14, 491,
	14, 743,
	14, 4170,
};
rom const uint8_t code_eu131Samples[] = {
		0x55,
		0x55,
		0x42,
		0x55,
		0x55,
		0x41,
};
rom const struct IrCode code_eu131Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu131Times,  
	code_eu131Samples,
};

/* Duplicate timing table, same as eu069 !
rom const uint16_t code_eu132Times[]  = {
	4, 499,
	4, 750,
	4, 4999,
};
*/
rom const uint8_t code_eu132Samples[] = {
			0x05,
		0x50,
		0x06,
		0x05,
		0x50,
		0x04,
};
rom const struct IrCode code_eu132Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu069Times,  
	code_eu132Samples,
};

/* Duplicate timing table, same as eu071 !
rom const uint16_t code_eu133Times[]  = {
	14, 491,
	14, 743,
	14, 4422,
};
*/
rom const uint8_t code_eu133Samples[] = {
			0x55,
		0x54,
		0x12,
		0x55,
		0x54,
		0x11,
};
rom const struct IrCode code_eu133Code  = {
	freq_to_timerval(38462),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu071Times,  
	code_eu133Samples,
};
rom const uint16_t code_eu134Times[]  = {
	13, 490,
	13, 741,
	13, 742,
	13, 5939,
};
rom const uint8_t code_eu134Samples[] = {
	0x40,
		0x0A,
		0x83,
		0x80,
		0x0A,
		0x81,
};
rom const struct IrCode code_eu134Code  = {
	freq_to_timerval(40000),
	24,		// # of pairs
	2,		// # of bits per index
	code_eu134Times,  
	code_eu134Samples,
};
rom const uint16_t code_eu135Times[]  = {
	6, 566,
	6, 851,
	6, 5188,
};
rom const uint8_t code_eu135Samples[] = {
	0x54,
		0x45,
		0x46,
		0x54,
		0x45,
		0x44,
};
rom const struct IrCode code_eu135Code  = {
	0,              // Non-pulsed code
	23,		// # of pairs
	2,		// # of bits per index
	code_eu135Times,  
	code_eu135Samples,
};


rom const uint16_t code_eu136Times[]  = {
	55, 57,
	55, 170,
	55, 3949,
	55, 9623,
	52, 0,
	898, 453,
	900, 226,
};
rom const uint8_t code_eu136Samples[] = {
		0xA0,
		0x00,
		0x00,
		0x04,
		0x92,
		0x49,
		0x24,
		0x00,
		0x00,
		0x00,
		0x92,
		0x49,
		0x2B,
		0x3D,
		0x00,
};

rom const struct IrCode code_eu136Code  = {
	freq_to_timerval(38462),
	38,		// # of pairs
	3,		// # of bits per index
	code_eu136Times,  
	code_eu136Samples,
};
rom const uint16_t code_eu137Times[]  = {
	86, 91,
	87, 90,
	87, 180,
	87, 8868,
	84, 0,
	174, 90,
};
rom const uint8_t code_eu137Samples[] = {
	0x14,
		0x95,
		0x4A,
		0x35,
		0x9A,
		0x4A,
		0xA5,
		0x1B,
		0x00,
};
rom const struct IrCode code_eu137Code  = {
	freq_to_timerval(35714),
	22,		// # of pairs
	3,		// # of bits per index
	code_eu137Times,  
	code_eu137Samples,
};
rom const uint16_t code_eu138Times[]  = {
	4, 1036,
	4, 1507,
	4, 3005,
};
rom const uint8_t code_eu138Samples[] = {
	0x05,
		0x60,
		0x54,
};
rom const struct IrCode code_eu138Code  = {
	0,              // Non-pulsed code
	11,		// # of pairs
	2,		// # of bits per index
	code_eu138Times,  
	code_eu138Samples,
};

rom const uint16_t code_eu139Times[]  = {
	0, 0,
	14, 141,
	14, 452,
	14, 607,
	14, 6310,
};
rom const uint8_t code_eu139Samples[] = {
		0x64,
		0x92,
		0x4A,
		0x24,
		0x92,
		0xE3,
		0x24,
		0x92,
		0x51,
		0x24,
		0x96,
		0x00,
};
rom const struct IrCode code_eu139Code  = {
	0,              // Non-pulsed code
	30,		// # of pairs
	3,		// # of bits per index
	code_eu139Times,  
	code_eu139Samples,
};

#endif


////////////////////////////////////////////////////////////////
#pragma idata bigdata
rom const struct IrCode *EUpowerCodes[]  = {
#ifdef EU_CODES
&code_eu006Code,  //Samsung
&code_eu030Code,  //LG
&code_eu009Code,  //Amstrad , PHILIPS
	&code_eu001Code,  //grunding
	&code_eu017Code,   //telefunken
&code_eu004Code,  //sony
&code_eu015Code,
	&code_eu016Code,	
	&code_eu018Code,
	&code_eu019Code,
	&code_eu020Code,
	&code_eu021Code,
    &code_eu000Code,
	&code_eu002Code,
	&code_eu003Code,
	&code_eu005Code,
	&code_eu007Code,
	&code_eu008Code,	
	&code_eu010Code,
	&code_eu011Code,
	&code_eu012Code,
	&code_eu013Code,
	&code_eu014Code,
		&code_eu022Code,
	&code_eu023Code,
	&code_eu024Code,
	&code_eu025Code,
	&code_eu026Code,
	&code_eu027Code,
	&code_eu028Code,
	&code_eu029Code,
    &code_eu031Code,
	&code_eu032Code,
	&code_eu033Code,
	&code_eu034Code,
	//&code_eu035Code, same as eu009
	&code_eu036Code,
	&code_eu037Code,
	&code_eu038Code,
	&code_eu039Code,
	&code_eu040Code,
	&code_eu041Code,
	&code_eu042Code,
	&code_eu043Code,
	&code_eu044Code,
	&code_eu045Code,
	&code_eu046Code,
	&code_eu047Code,
	&code_eu048Code,
	&code_eu049Code,
	&code_eu050Code,
	&code_eu051Code,
	&code_eu052Code,
	&code_eu053Code,
	&code_eu054Code,
	&code_eu055Code,
	&code_eu056Code,
	//&code_eu057Code, same as eu008
	&code_eu058Code,
	&code_eu059Code,
	&code_eu060Code,
	&code_eu061Code,
	&code_eu062Code,
	&code_eu063Code,
	&code_eu064Code,
	&code_eu065Code,
	&code_eu066Code,
	&code_eu067Code,
	&code_eu068Code,
	&code_eu069Code,
	&code_eu070Code,
	&code_eu071Code,
	&code_eu072Code,
	&code_eu073Code,
	&code_eu074Code,
	&code_eu075Code,
	&code_eu076Code,
	&code_eu077Code,
	&code_eu078Code,
	&code_eu079Code,
	&code_eu080Code,
	&code_eu081Code,
	&code_eu082Code,
	&code_eu083Code,
	&code_eu084Code,
	&code_eu085Code,
	&code_eu086Code,
	&code_eu087Code,
	&code_eu088Code,
	&code_eu089Code,
	&code_eu090Code,
	&code_eu091Code,
	&code_eu092Code,
	&code_eu093Code,
	&code_eu094Code,
	&code_eu095Code,
	&code_eu096Code,
	&code_eu097Code,
	&code_eu098Code,
	&code_eu099Code,
	&code_eu100Code,
	&code_eu101Code,
	&code_eu102Code,
	&code_eu103Code,
	&code_eu104Code,
	&code_eu105Code,
	&code_eu106Code,
	&code_eu107Code,
	&code_eu108Code,
	&code_eu109Code,
	&code_eu110Code,
	&code_eu111Code,
	&code_eu112Code,
	&code_eu113Code,
	&code_eu114Code,
	&code_eu115Code,
	&code_eu116Code,
	&code_eu117Code,
	&code_eu118Code,
	&code_eu119Code,
	&code_eu120Code,
	&code_eu121Code,
	&code_eu122Code,
	&code_eu123Code,
	&code_eu124Code,
	&code_eu125Code,
	&code_eu126Code,
	&code_eu127Code,
	&code_eu128Code,
	&code_eu129Code,
	&code_eu130Code,
	&code_eu131Code,
	&code_eu132Code,
	&code_eu133Code,
	&code_eu134Code,
	&code_eu135Code,
	&code_eu136Code,
	&code_eu137Code,
	&code_eu138Code,
	&code_eu139Code,
#endif
};
#pragma idata
